==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/config_wizard/translations/config_wizard_es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IM Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/config_wizard/translations/config_wizard_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
